```
Usage: vcd vapp copy [OPTIONS] <vapp_name>

Options:
  -n, --name <vapp_new_name>      name of copy vapp  [required]
  -v, --vdc <vdc>                 virtual datacenter name where need to copy
                                  vapp
  -d, --description <description>
                                  description of copy vapp
  -h, --help                      Show this message and exit.

```
